Config

Struct Config 

pub struct Config { /* private fields */ }
Available on crate features ble and unstable only.
Bluetooth controller configuration.

Implementations

Source

impl Config

pub fn with_task_priority(self, task_priority: u8) -> Self

Assign the given value to the task_priority field.

pub fn task_priority(&self) -> u8

The priority of the RTOS task.

pub fn with_task_stack_size(self, task_stack_size: u16) -> Self

Assign the given value to the task_stack_size field.

pub fn task_stack_size(&self) -> u16

The stack size of the RTOS task.

pub fn with_max_connections(self, max_connections: u16) -> Self

Assign the given value to the max_connections field.

pub fn max_connections(&self) -> u16

The maximum number of simultaneous connections.

Range: 1 - 70

pub fn with_qa_test_mode(self, qa_test_mode: bool) -> Self

Assign the given value to the qa_test_mode field.

pub fn qa_test_mode(&self) -> bool

Enable QA test mode.

pub fn with_bqb_test(self, bqb_test: bool) -> Self

Assign the given value to the bqb_test field.

pub fn bqb_test(&self) -> bool

Enable BQB test mode.

pub fn with_ll_resolv_list_size(self, ll_resolv_list_size: u16) -> Self

Assign the given value to the ll_resolv_list_size field.

pub fn ll_resolv_list_size(&self) -> u16

Size of the resolvable private address list.

pub fn with_ll_sync_list_cnt(self, ll_sync_list_cnt: u8) -> Self

Assign the given value to the ll_sync_list_cnt field.

pub fn ll_sync_list_cnt(&self) -> u8

Maximum number of periodic advertiser list.

Range: 1 - 5

pub fn with_ll_sync_cnt(self, ll_sync_cnt: u8) -> Self

Assign the given value to the ll_sync_cnt field.

pub fn ll_sync_cnt(&self) -> u8

Maximum number of periodic advertising syncs.

Range: 0 - 3

pub fn with_ll_rsp_dup_list_count(self, ll_rsp_dup_list_count: u16) -> Self

Assign the given value to the ll_rsp_dup_list_count field.

pub fn ll_rsp_dup_list_count(&self) -> u16

Count of duplicated lists for scan response packets

Range: 1 - 100

pub fn with_ll_adv_dup_list_count(self, ll_adv_dup_list_count: u16) -> Self

Assign the given value to the ll_adv_dup_list_count field.

pub fn ll_adv_dup_list_count(&self) -> u16

Count of duplicated lists for advertising packets

Range: 1 - 100

pub fn with_verify_access_address(self, verify_access_address: bool) -> Self

Assign the given value to the verify_access_address field.

pub fn verify_access_address(&self) -> bool

Enables verification of the Access Address within the CONNECT_IND PDU.

Enabling this option will add stricter verification of the Access Address in the CONNECT_IND PDU. This improves security by ensuring that only connection requests with valid Access Addresses are accepted. If disabled, only basic checks are applied, improving compatibility.

pub fn with_channel_assessment(self, channel_assessment: bool) -> Self

Assign the given value to the channel_assessment field.

pub fn channel_assessment(&self) -> bool

Enable BLE channel assessment.

pub fn with_default_tx_power(self, default_tx_power: TxPower) -> Self

Assign the given value to the default_tx_power field.

pub fn default_tx_power(&self) -> TxPower

Default TX power.

pub fn with_hci_high_buffer_count(self, hci_high_buffer_count: u16) -> Self

Assign the given value to the hci_high_buffer_count field.

pub fn hci_high_buffer_count(&self) -> u16

High Priority HCI Event Buffer count

pub fn with_hci_low_buffer_count(self, hci_low_buffer_count: u16) -> Self

Assign the given value to the hci_low_buffer_count field.

pub fn hci_low_buffer_count(&self) -> u16

Low Priority HCI Event Buffer count

pub fn with_whitelist_size(self, whitelist_size: u8) -> Self

Assign the given value to the whitelist_size field.

pub fn whitelist_size(&self) -> u8

Size of the whitelist.

pub fn with_acl_buf_size(self, acl_buf_size: u16) -> Self

Assign the given value to the acl_buf_size field.

pub fn acl_buf_size(&self) -> u16

Buffer size of ACL (Asynchronous Connection-Less) data

pub fn with_acl_buf_count(self, acl_buf_count: u16) -> Self

Assign the given value to the acl_buf_count field.

pub fn acl_buf_count(&self) -> u16

Buffer count of ACL data

pub fn with_hci_evt_buf_size(self, hci_evt_buf_size: u16) -> Self

Assign the given value to the hci_evt_buf_size field.

pub fn hci_evt_buf_size(&self) -> u16

Buffer size for HCI event data

pub fn with_multi_adv_instances(self, multi_adv_instances: u16) -> Self

Assign the given value to the multi_adv_instances field.

pub fn multi_adv_instances(&self) -> u16

Maximum number of extended advertising instances.

pub fn with_ext_adv_max_size(self, ext_adv_max_size: u16) -> Self

Assign the given value to the ext_adv_max_size field.

pub fn ext_adv_max_size(&self) -> u16

Maximum size of extended advertising data

Range: 0 - 1650

pub fn with_dis_scan_backoff(self, dis_scan_backoff: bool) -> Self

Assign the given value to the dis_scan_backoff field.

pub fn dis_scan_backoff(&self) -> bool

Disable scan backoff

pub fn with_scan_backoff_max(self, scan_backoff_max: u16) -> Self

Assign the given value to the scan_backoff_max field.

pub fn scan_backoff_max(&self) -> u16

The value of upperlimitmax during scan backoff procedure

The value of upperlimitmax needs to be a power of 2.

Range: 1 - 256

pub fn with_cca(self, cca: bool) -> Self

Assign the given value to the cca field.

pub fn cca(&self) -> bool

Enable BLE Clear Channel Assessment (CCA).

pub fn with_cca_threshold(self, cca_threshold: u8) -> Self

Assign the given value to the cca_threshold field.

pub fn cca_threshold(&self) -> u8

Absolute value of hardware-triggered CCA threshold.

The CCA threshold is always negative.

If the channel assessment result exceeds the CCA threshold (e.g. -75 dBm), indicating the channel is busy, the hardware will not transmit packets on that channel.

Range: 20 dBm - 100 dBm

pub fn with_data_length_zero_aux(self, data_length_zero_aux: bool) -> Self

Assign the given value to the data_length_zero_aux field.

pub fn data_length_zero_aux(&self) -> bool

Enable / disable auxiliary packets when the extended ADV data length is zero.

pub fn with_disconnect_llcp_conn_update( self, disconnect_llcp_conn_update: bool, ) -> Self

Assign the given value to the disconnect_llcp_conn_update field.

pub fn disconnect_llcp_conn_update(&self) -> bool

Disconnect when Instant Passed (0x28) occurs during ACL connection update.

pub fn with_disconnect_llcp_chan_map_update( self, disconnect_llcp_chan_map_update: bool, ) -> Self

Assign the given value to the disconnect_llcp_chan_map_update field.

pub fn disconnect_llcp_chan_map_update(&self) -> bool

Disconnect when Instant Passed (0x28) occurs during ACL channel map update.

pub fn with_disconnect_llcp_phy_update( self, disconnect_llcp_phy_update: bool, ) -> Self

Assign the given value to the disconnect_llcp_phy_update field.

pub fn disconnect_llcp_phy_update(&self) -> bool

Disconnect when Instant Passed (0x28) occurs during ACL PHY update.